@@ -1,11 +1,15 @@
 import copy
 import subprocess
 import warnings
+import os
 
 from nctoolkit.api import open_data
 from nctoolkit.cleanup import cleanup
 from nctoolkit.flatten import str_flatten
-from nctoolkit.runthis import run_this
+from nctoolkit.runthis import run_this, run_cdo
+from nctoolkit.temp_file import temp_file
+from nctoolkit.session import append_safe
+from nctoolkit.session import remove_safe
 
 
 def bottom(self):
